@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 	}
 
 	info->setText( 
-		"<b>SMPlayer</b> &copy; 2006-2009 Ricardo Villalba &lt;rvm@escomposlinux.org&gt;<br><br>"
+		"<b>SMPlayer</b> &copy; 2006-2010 Ricardo Villalba &lt;rvm@escomposlinux.org&gt;<br><br>"
 		"<b>" + tr("Version: %1").arg(smplayerVersion()) + "</b>" +
 #if PORTABLE_APP
                 " (" + tr("Portable Edition") + ")" +
@@ -61,7 +61,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
         link("http://smplayer.berlios.de") + "<br>" + 
         link("http://smplayer.sf.net") + 
         "<br><br>" +
-		tr("Get help in our forum:") +"<br>" + link("http://smplayer.berlios.de/forums") +
+		tr("Get help in our forum:") +"<br>" + link("http://smplayer.berlios.de/forum") +
         "<br><br>" +
 		tr("You can support SMPlayer by making a donation.") +" "+
 		link("https://sourceforge.net/donate/index.php?group_id=185512", tr("More info"))
@@ -157,7 +157,9 @@ QString About::getTranslators() {
 #endif
          trad(tr("German"), "Henrikx <henrikx@users.sourceforge.net>") + 
 		 trad(tr("Slovak"), "Sweto <peter.mendel@gmail.com>") +
-		 trad(tr("Italian"), "Giancarlo Scola <scola.giancarlo@libero.it>") +
+		 trad(tr("Italian"), QStringList()
+                        << "greengreat <gmeildeno@gmail.com>"
+			<< "Giancarlo Scola <scola.giancarlo@libero.it>") +
          trad(tr("French"), QStringList() 
 			<< "Olivier g <1got@caramail.com>"
 			<< "Temet <goondy@free.fr>"
@@ -191,7 +193,7 @@ QString About::getTranslators() {
          trad(tr("Romanian"), "DoruH <DoruHushHush@gmail.com>") + 
          trad(tr("Portuguese - Portugal"), QStringList()
 			<< "Waxman <waxman.pt@gmail.com>"
-			<< QString::fromUtf8("Sérgio Marques <contatica@netcabo.pt>") ) +
+			<< QString::fromUtf8("Sérgio Marques <smarquespt@gmail.com>") ) +
 		trad(tr("Greek"), "my80s <wamy80s@gmail.com>") +
 		trad(tr("Finnish"), "peeaivo <peeaivo@gmail.com>") +
 		trad(tr("Korean"), "Heesu Yoon <imsu30@gmail.com>") +
@@ -204,6 +206,7 @@ QString About::getTranslators() {
 		trad(tr("Galician"), "Miguel Branco <mgl.branco@gmail.com>") +
 		trad(tr("Vietnamese"), QString::fromUtf8("Lê Xuân Thảo <thaolx@gmail.com>")) +
 		trad(tr("Estonian"), QString::fromUtf8("Olav Mägi <olav.magi@hotmail.com>")) +
+                trad(tr("Lithuanian"), "Freemail <ricka_g@freemail.lt>") +
 #ifndef TRANS_TABLE
         "</ul>");
 #else
