@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -134,8 +134,12 @@ public slots:
 	virtual void checkStayOnTop(Core::State);
 	void toggleStayOnTop();
 
-	virtual void toggleFrameCounter();
-	virtual void toggleFrameCounter(bool);
+	void setForceCloseOnFinish(int n) { arg_close_on_finish = n; };
+	int forceCloseOnFinish() { return arg_close_on_finish; };
+
+	void setForceStartInFullscreen(int n) { arg_start_in_fullscreen = n; };
+	int forceStartInFullscreen() { return arg_start_in_fullscreen; };
+
 
 protected slots:
 	virtual void closeWindow();
@@ -253,6 +257,8 @@ protected slots:
 
 signals:
 	void frameChanged(int);
+	void ABMarkersChanged(int secs_a, int secs_b);
+	void videoInfoChanged(int width, int height, double fps);
 	void timeChanged(QString time_ready_to_print);
 
 	void cursorNearTop(QPoint);
@@ -337,6 +343,9 @@ protected:
 	MyAction * forward2Act;
 	MyAction * forward3Act;
 	MyAction * repeatAct;
+	MyAction * setAMarkerAct;
+	MyAction * setBMarkerAct;
+	MyAction * clearABMarkersAct;
 	MyAction * gotoAct;
 
 	// Menu Speed
@@ -403,7 +412,6 @@ protected:
 	// Menu Options
 	MyAction * showPlaylistAct;
 	MyAction * showPropertiesAct;
-	MyAction * frameCounterAct;
 	MyAction * motionVectorsAct;
 	MyAction * showPreferencesAct;
 	MyAction * showLogMplayerAct;
@@ -449,6 +457,9 @@ protected:
 	MyAction * nextAspectAct;
 	MyAction * nextWheelFunctionAct;
 
+	MyAction * showFilenameAct;
+	MyAction * toggleDeinterlaceAct;
+
 	// Moving and zoom
 	MyAction * moveUpAct;
 	MyAction * moveDownAct;
@@ -461,6 +472,11 @@ protected:
 	MyAction * autoZoom169Act;
 	MyAction * autoZoom235Act;
 
+#if USE_MPLAYER_PANSCAN
+	MyAction * incPanscanAct;
+	MyAction * decPanscanAct;
+#endif
+
 	// OSD Action Group 
 	MyActionGroup * osdGroup;
 	MyAction * osdNoneAct;
@@ -593,10 +609,11 @@ protected:
 	QMenu * stereomode_menu;
 
 	QMenu * speed_menu;
+	QMenu * ab_menu; // A-B menu
 	QMenu * videofilter_menu;
 	QMenu * audiofilter_menu;
 	QMenu * logs_menu;
-	QMenu * panscan_menu;
+	QMenu * zoom_menu;
 	QMenu * rotate_menu;
 	QMenu * ontop_menu;
 #if USE_ADAPTER
@@ -630,6 +647,10 @@ protected:
 
 	QString pending_actions_to_run;
 
+	// Force settings from command line
+	int arg_close_on_finish; // -1 = not set, 1 = true, 0 = false
+	int arg_start_in_fullscreen; // -1 = not set, 1 = true, 0 = false
+
 private:
 	QString default_style;
 
