@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -135,4 +135,10 @@
 #endif
 
 
+// If 1, smplayer will add support for the mplayer slave command
+// "panscan".
+
+#define USE_MPLAYER_PANSCAN 0
+
+
 #endif
