@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -54,6 +54,10 @@ DefaultGui::DefaultGui( QWidget * parent, Qt::WindowFlags flags )
              this, SLOT(displayTime(QString)) );
     connect( this, SIGNAL(frameChanged(int)),
              this, SLOT(displayFrame(int)) );
+	connect( this, SIGNAL(ABMarkersChanged(int,int)),
+             this, SLOT(displayABSection(int,int)) );
+	connect( this, SIGNAL(videoInfoChanged(int,int,double)),
+             this, SLOT(displayVideoInfo(int,int,double)) );
 
 	connect( this, SIGNAL(cursorNearBottom(QPoint)), 
              this, SLOT(showFloatingControl(QPoint)) );
@@ -119,6 +123,17 @@ void DefaultGui::createActions() {
 	forwardbutton_action = new SeekingButton(forward_actions, this);
 	forwardbutton_action->setObjectName("forwardbutton_action");
 #endif
+
+	// Statusbar
+	viewVideoInfoAct = new MyAction(this, "toggle_video_info" );
+	viewVideoInfoAct->setCheckable(true);
+	connect( viewVideoInfoAct, SIGNAL(toggled(bool)),
+             video_info_display, SLOT(setVisible(bool)) );
+
+	viewFrameCounterAct = new MyAction( this, "toggle_frame_counter" );
+	viewFrameCounterAct->setCheckable( true );
+	connect( viewFrameCounterAct, SIGNAL(toggled(bool)),
+             frame_display, SLOT(setVisible(bool)) );
 }
 
 #if AUTODISABLE_ACTIONS
@@ -145,6 +160,12 @@ void DefaultGui::createMenus() {
 	toolbar_menu->addAction(toolbar2->toggleViewAction());
 	optionsMenu->addSeparator();
 	optionsMenu->addMenu(toolbar_menu);
+
+	statusbar_menu = new QMenu(this);
+	statusbar_menu->addAction(viewVideoInfoAct);
+	statusbar_menu->addAction(viewFrameCounterAct);
+
+	optionsMenu->addMenu(statusbar_menu);
 }
 
 QMenu * DefaultGui::createPopupMenu() {
@@ -353,6 +374,16 @@ void DefaultGui::createStatusBar() {
 	frame_display->setText("88888888");
 	frame_display->setMinimumSize(frame_display->sizeHint());
 
+	ab_section_display = new QLabel( statusBar() );
+	ab_section_display->setAlignment(Qt::AlignRight);
+	ab_section_display->setFrameShape(QFrame::NoFrame);
+//	ab_section_display->setText("A:0:00:00 B:0:00:00");
+//	ab_section_display->setMinimumSize(ab_section_display->sizeHint());
+
+	video_info_display = new QLabel( statusBar() );
+	video_info_display->setAlignment(Qt::AlignRight);
+	video_info_display->setFrameShape(QFrame::NoFrame);
+
 	statusBar()->setAutoFillBackground(TRUE);
 
 	ColorUtils::setBackgroundColor( statusBar(), QColor(0,0,0) );
@@ -361,8 +392,15 @@ void DefaultGui::createStatusBar() {
 	ColorUtils::setForegroundColor( time_display, QColor(255,255,255) );
 	ColorUtils::setBackgroundColor( frame_display, QColor(0,0,0) );
 	ColorUtils::setForegroundColor( frame_display, QColor(255,255,255) );
+	ColorUtils::setBackgroundColor( ab_section_display, QColor(0,0,0) );
+	ColorUtils::setForegroundColor( ab_section_display, QColor(255,255,255) );
+	ColorUtils::setBackgroundColor( video_info_display, QColor(0,0,0) );
+	ColorUtils::setForegroundColor( video_info_display, QColor(255,255,255) );
 	statusBar()->setSizeGripEnabled(FALSE);
 
+	statusBar()->addPermanentWidget( video_info_display );
+	statusBar()->addPermanentWidget( ab_section_display );
+
     statusBar()->showMessage( tr("Welcome to SMPlayer") );
 	statusBar()->addPermanentWidget( frame_display, 0 );
 	frame_display->setText( "0" );
@@ -372,6 +410,8 @@ void DefaultGui::createStatusBar() {
 
 	time_display->show();
 	frame_display->hide();
+	ab_section_display->show();
+	video_info_display->hide();
 }
 
 void DefaultGui::retranslateStrings() {
@@ -380,6 +420,9 @@ void DefaultGui::retranslateStrings() {
 	toolbar_menu->menuAction()->setText( tr("&Toolbars") );
 	toolbar_menu->menuAction()->setIcon( Images::icon("toolbars") );
 
+	statusbar_menu->menuAction()->setText( tr("Status&bar") );
+	statusbar_menu->menuAction()->setIcon( Images::icon("statusbar") );
+
 	toolbar1->setWindowTitle( tr("&Main toolbar") );
 	toolbar1->toggleViewAction()->setIcon(Images::icon("main_toolbar"));
 
@@ -388,6 +431,9 @@ void DefaultGui::retranslateStrings() {
 
 	select_audio->setText( tr("Audio") );
 	select_subtitle->setText( tr("Subtitle") );
+
+	viewVideoInfoAct->change(Images::icon("view_video_info"), tr("&Video info") );
+	viewFrameCounterAct->change( Images::icon("frame_counter"), tr("&Frame counter") );
 }
 
 
@@ -402,14 +448,29 @@ void DefaultGui::displayFrame(int frame) {
 	}
 }
 
+void DefaultGui::displayABSection(int secs_a, int secs_b) {
+	QString s;
+	if (secs_a > -1) s = tr("A:%1").arg(Helper::formatTime(secs_a));
+
+	if (secs_b > -1) {
+		if (!s.isEmpty()) s += " ";
+		s += tr("B:%1").arg(Helper::formatTime(secs_b));
+	}
+
+	ab_section_display->setText( s );
+
+	ab_section_display->setShown( !s.isEmpty() );
+}
+
+void DefaultGui::displayVideoInfo(int width, int height, double fps) {
+	video_info_display->setText(tr("%1x%2 %3 fps", "width + height + fps").arg(width).arg(height).arg(fps));
+}
+
 void DefaultGui::updateWidgets() {
 	qDebug("DefaultGui::updateWidgets");
 
 	BaseGuiPlus::updateWidgets();
 
-	// Frame counter
-	frame_display->setVisible( pref->show_frame_counter );
-
 	panel->setFocus();
 }
 
@@ -557,6 +618,9 @@ void DefaultGui::saveConfig() {
 
 	set->beginGroup( "default_gui");
 
+	set->setValue("video_info", viewVideoInfoAct->isChecked());
+	set->setValue("frame_counter", viewFrameCounterAct->isChecked());
+
 	set->setValue("fullscreen_toolbar1_was_visible", fullscreen_toolbar1_was_visible);
 	set->setValue("fullscreen_toolbar2_was_visible", fullscreen_toolbar2_was_visible);
 	set->setValue("compact_toolbar1_was_visible", compact_toolbar1_was_visible);
@@ -589,6 +653,9 @@ void DefaultGui::loadConfig() {
 
 	set->beginGroup( "default_gui");
 
+	viewVideoInfoAct->setChecked(set->value("video_info", false).toBool());
+	viewFrameCounterAct->setChecked(set->value("frame_counter", false).toBool());
+
 	fullscreen_toolbar1_was_visible = set->value("fullscreen_toolbar1_was_visible", fullscreen_toolbar1_was_visible).toBool();
 	fullscreen_toolbar2_was_visible = set->value("fullscreen_toolbar2_was_visible", fullscreen_toolbar2_was_visible).toBool();
 	compact_toolbar1_was_visible = set->value("compact_toolbar1_was_visible", compact_toolbar1_was_visible).toBool();
