@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,6 +42,12 @@
 #include <QBuffer>
 #endif
 
+//#define NO_SMPLAYER_SUPPORT
+
+#ifndef NO_SMPLAYER_SUPPORT
+#include "images.h"
+#endif
+
 #define COL_LANG 0
 #define COL_NAME 1
 #define COL_FORMAT 2
@@ -212,6 +218,16 @@ void FindSubtitlesWindow::retranslateStrings() {
 	// Actions
 	downloadAct->setText( tr("&Download") );
 	copyLinkAct->setText( tr("&Copy link to clipboard") );
+
+	// Icons
+#ifndef NO_SMPLAYER_SUPPORT
+	download_button->setIcon( Images::icon("download") );
+	configure_button->setIcon( Images::icon("prefs") );
+	refresh_button->setIcon( Images::icon("refresh") );
+
+	downloadAct->setIcon( Images::icon("download") );
+	copyLinkAct->setIcon( Images::icon("copy") );
+#endif
 }
 
 void FindSubtitlesWindow::setMovie(QString filename) {
@@ -241,10 +257,14 @@ void FindSubtitlesWindow::refresh() {
 }
 
 void FindSubtitlesWindow::updateRefreshButton() {
+	qDebug("FindSubtitlesWindow::updateRefreshButton: state: %d", downloader->state());
+/*
 	QString file = file_chooser->lineEdit()->text();
 	bool enabled = ( (!file.isEmpty()) && (QFile::exists(file)) && 
                      (downloader->state()==QHttp::Unconnected) );
 	refresh_button->setEnabled(enabled);
+*/
+	refresh_button->setEnabled(true);
 }
 
 void FindSubtitlesWindow::currentItemChanged(const QModelIndex & current, const QModelIndex & /*previous*/) {
@@ -276,6 +296,8 @@ QString FindSubtitlesWindow::language() {
 }
 
 void FindSubtitlesWindow::showError(QString error) {
+	status->setText( tr("Download failed") );
+
 	QMessageBox::information(this, tr("Error"),
                              tr("Download failed: %1.")
                              .arg(error));
