@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,8 +99,7 @@ QString OSParser::calculateHash(QString filename) {
 		in >> a ; hash += a;
 	};
 
-	QString hexhash("");
-	hexhash.setNum(hash,16);
+	QString hexhash = QString("%1").arg(hash, 16, 16, QChar('0'));
 
 	return hexhash;
 }
