@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -86,7 +86,11 @@ void MediaSettings::reset() {
 	audio_use_channels = pref->initial_audio_channels; //ChDefault; // (0)
 	stereo_mode = pref->initial_stereo_mode; //Stereo; // (0)
 
-	panscan_factor = pref->initial_panscan_factor; // 1.0;
+	zoom_factor = pref->initial_zoom_factor; // 1.0;
+
+#if USE_MPLAYER_PANSCAN
+	panscan_factor = 0;
+#endif
 
 	starting_time = -1; // Not set yet.
 
@@ -94,6 +98,10 @@ void MediaSettings::reset() {
 	flip = false;
 	mirror = false;
 
+	loop = false;
+	A_marker = -1;
+	B_marker = -1;
+
 	is264andHD = false;
 
 	forced_demuxer="";
@@ -212,12 +220,20 @@ void MediaSettings::list() {
 	qDebug("  audio_use_channels: %d", audio_use_channels);
 	qDebug("  stereo_mode: %d", stereo_mode);
 
-	qDebug("  panscan_factor: %f", panscan_factor);
+	qDebug("  zoom_factor: %f", zoom_factor);
+
+#if USE_MPLAYER_PANSCAN
+	qDebug("  panscan_factor: %f", zoom_factor);
+#endif
 
 	qDebug("  rotate: %d", rotate);
 	qDebug("  flip: %d", flip);
 	qDebug("  mirror: %d", mirror);
 
+	qDebug("  loop: %d", loop);
+	qDebug("  A_marker: %d", A_marker);
+	qDebug("  B_marker: %d", B_marker);
+
 	qDebug("  forced_demuxer: '%s'", forced_demuxer.toUtf8().data());
 	qDebug("  forced_video_codec: '%s'", forced_video_codec.toUtf8().data());
 	qDebug("  forced_audio_codec: '%s'", forced_video_codec.toUtf8().data());
@@ -298,12 +314,20 @@ void MediaSettings::save(QSettings * set) {
 	set->setValue( "audio_use_channels", audio_use_channels);
 	set->setValue( "stereo_mode", stereo_mode);
 
-	set->setValue( "panscan_factor", panscan_factor);
+	set->setValue( "zoom_factor", zoom_factor);
+
+#if USE_MPLAYER_PANSCAN
+	set->setValue( "panscan_factor", zoom_factor);
+#endif
 
 	set->setValue( "rotate", rotate );
 	set->setValue( "flip", flip);
 	set->setValue( "mirror", mirror);
 
+	set->setValue( "loop", loop);
+	set->setValue( "A_marker", A_marker);
+	set->setValue( "B_marker", B_marker);
+
 	set->setValue( "forced_demuxer", forced_demuxer);
 	set->setValue( "forced_video_codec", forced_video_codec);
 	set->setValue( "forced_audio_codec", forced_audio_codec);
@@ -385,12 +409,20 @@ void MediaSettings::load(QSettings * set) {
 	audio_use_channels = set->value( "audio_use_channels", audio_use_channels).toInt();
 	stereo_mode = set->value( "stereo_mode", stereo_mode).toInt();
 
+	zoom_factor = set->value( "zoom_factor", zoom_factor).toDouble();
+
+#if USE_MPLAYER_PANSCAN
 	panscan_factor = set->value( "panscan_factor", panscan_factor).toDouble();
+#endif
 
 	rotate = set->value( "rotate", rotate).toInt();
 	flip = set->value( "flip", flip).toBool();
 	mirror = set->value( "mirror", mirror).toBool();
 
+	loop = set->value( "loop", loop).toBool();
+	A_marker = set->value( "A_marker", A_marker).toInt();
+	B_marker = set->value( "B_marker", B_marker).toInt();
+
 	forced_demuxer = set->value( "forced_demuxer", forced_demuxer).toString();
 	forced_video_codec = set->value( "forced_video_codec", forced_video_codec).toString();
 	forced_audio_codec = set->value( "forced_audio_codec", forced_audio_codec).toString();
