@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -112,12 +112,20 @@ public:
 	int audio_use_channels;
 	int stereo_mode;
 
-	double panscan_factor; // mplayerwindow zoom
+	double zoom_factor; // mplayerwindow zoom
+
+#if USE_MPLAYER_PANSCAN
+	double panscan_factor;
+#endif
 
 	int rotate;
 	bool flip; //!< Flip image
 	bool mirror; //!< Mirrors the image on the Y axis.
 
+	bool loop; //!< Loop. If true repeat the file
+	int A_marker;
+	int B_marker;
+
 	// This a property of the video and it should be
     // in mediadata, but we have to save it to preserve 
 	// this data among restarts.
