@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,7 +63,9 @@ signals:
 	void receivedResolvingMessage(QString);
 	void receivedScreenshot(QString);
 	void receivedUpdatingFontCache();
+	void receivedScanningFont(QString);
 
+	void receivedStreamTitle(QString);
 	void receivedStreamTitleAndUrl(QString,QString);
 
 	void failedToParseMplayerVersion(QString line_with_mplayer_version);
