@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,12 +50,10 @@ Screen::Screen(QWidget* parent, Qt::WindowFlags f) : QWidget(parent, f )
 	last_cursor_pos = QPoint(0,0);
 #endif
 
-	QTimer *timer = new QTimer(this);
-	connect( timer, SIGNAL(timeout()), this, SLOT(checkMousePos()) );
-#if NEW_MOUSE_CHECK_POS
-	timer->start(500);
-#else
-	timer->start(2000);
+	check_mouse_timer = new QTimer(this);
+	connect( check_mouse_timer, SIGNAL(timeout()), this, SLOT(checkMousePos()) );
+#if !NEW_MOUSE_CHECK_POS
+	check_mouse_timer->start(2000);
 #endif
 
 	// Change attributes
@@ -65,6 +63,11 @@ Screen::Screen(QWidget* parent, Qt::WindowFlags f) : QWidget(parent, f )
 	setAttribute(Qt::WA_PaintOnScreen);
 	setAttribute(Qt::WA_PaintUnclipped);
 	//setAttribute(Qt::WA_PaintOutsidePaintEvent);
+
+#if NEW_MOUSE_CHECK_POS
+	setAutoHideInterval(1000);
+	setAutoHideCursor(false);
+#endif
 }
 
 Screen::~Screen() {
@@ -78,10 +81,30 @@ void Screen::paintEvent( QPaintEvent * e ) {
 }
 
 #if NEW_MOUSE_CHECK_POS
+void Screen::setAutoHideCursor(bool b) {
+	qDebug("Screen::setAutoHideCursor: %d", b);
+
+	autohide_cursor = b;
+	if (autohide_cursor) {
+		check_mouse_timer->setInterval(autohide_interval);
+		check_mouse_timer->start();
+	} else {
+		check_mouse_timer->stop();
+	}
+}
+
 void Screen::checkMousePos() {
 	//qDebug("Screen::checkMousePos");
+
+	if (!autohide_cursor) {
+		setCursor(QCursor(Qt::ArrowCursor));
+		return;
+	}
+
 	QPoint pos = mapFromGlobal(QCursor::pos());
 
+	//qDebug("Screen::checkMousePos: x: %d, y: %d", pos.x(), pos.y());
+
 	if (mouse_last_position != pos) {
 		setCursor(QCursor(Qt::ArrowCursor));
 	} else {
@@ -116,6 +139,20 @@ void Screen::mouseMoveEvent( QMouseEvent * e ) {
 }
 #endif
 
+void Screen::playingStarted() {
+#if NEW_MOUSE_CHECK_POS
+	qDebug("Screen::playingStarted");
+	setAutoHideCursor(true);
+#endif
+}
+
+void Screen::playingStopped() {
+#if NEW_MOUSE_CHECK_POS
+	qDebug("Screen::playingStopped");
+	setAutoHideCursor(false);
+#endif
+}
+
 /* ---------------------------------------------------------------------- */
 
 MplayerLayer::MplayerLayer(QWidget* parent, Qt::WindowFlags f) 
@@ -149,12 +186,16 @@ void MplayerLayer::playingStarted() {
 	qDebug("MplayerLayer::playingStarted");
 	repaint();
 	playing = true;
+
+	Screen::playingStarted();
 }
 
 void MplayerLayer::playingStopped() {
 	qDebug("MplayerLayer::playingStopped");
 	playing = false;
 	repaint();
+
+	Screen::playingStopped();
 }
 
 /* ---------------------------------------------------------------------- */
