@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "prefadvanced.h"
 #include "images.h"
 #include "preferences.h"
+#include "paths.h"
 #include <QColorDialog>
 
 PrefAdvanced::PrefAdvanced(QWidget * parent, Qt::WindowFlags f)
@@ -100,6 +101,8 @@ void PrefAdvanced::setData(Preferences * pref) {
     setSaveMplayerLog( pref->autosave_mplayer_log );
     setMplayerLogName( pref->mplayer_log_saveto );
 
+	setSaveSmplayerLog( pref->save_smplayer_log );
+
 	setUseShortNames( pref->use_short_pathnames );
 }
 
@@ -150,6 +153,8 @@ void PrefAdvanced::getData(Preferences * pref) {
     pref->autosave_mplayer_log = saveMplayerLog();
     pref->mplayer_log_saveto = mplayerLogName();
 
+	pref->save_smplayer_log = saveSmplayerLog();
+
 	pref->use_short_pathnames = useShortNames();
 }
 
@@ -337,6 +342,14 @@ QString PrefAdvanced::mplayerLogName() {
     return log_mplayer_save_name->text();
 }
 
+void PrefAdvanced::setSaveSmplayerLog(bool b) {
+	log_smplayer_save_check->setChecked(b);
+}
+
+bool PrefAdvanced::saveSmplayerLog(){
+    return log_smplayer_save_check->isChecked();
+}
+
 
 void PrefAdvanced::createHelp() {
 	clearHelp();
@@ -436,6 +449,10 @@ void PrefAdvanced::createHelp() {
            "This information can be very useful for the developer in case "
            "you find a bug." ) );
 
+	setWhatsThis(log_smplayer_save_check, tr("Save SMPlayer log to file"),
+		tr("If this option is checked, the SMPlayer log wil be recorded to %1")
+          .arg( "<i>"+ Paths::configPath() + "/smplayer_log.txt</i>" ) );
+
 	setWhatsThis(log_mplayer_check, tr("Log MPlayer output"),
 		tr("If checked, SMPlayer will store the output of MPlayer "
            "(you can see it in <b>Options -> View logs -> MPlayer</b>). "
