@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,6 +99,9 @@ protected:
 	void setLogMplayer(bool b);
 	bool logMplayer();
 
+	void setMplayerLogVerbose(bool b);
+	bool mplayerLogVerbose();
+
 	void setLogSmplayer(bool b);
 	bool logSmplayer();
 
@@ -111,6 +114,9 @@ protected:
     void setMplayerLogName(QString filter);
     QString mplayerLogName();
 
+	void setSaveSmplayerLog(bool b);
+	bool saveSmplayerLog();
+
 protected:
 	virtual void retranslateStrings();
 
