@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -96,6 +96,10 @@ public:
 	bool disable_screensaver;
 #endif
 
+#ifndef Q_OS_WIN
+	bool disable_video_filters_with_vdpau;
+#endif
+
 	// Audio
 	bool use_soft_vol;
 	int softvol_max;
@@ -116,8 +120,8 @@ public:
 	double mc_value;
 
 	// Misc
-	bool loop; 	//!< Loop. If true repeat the file
 	int osd;
+	int osd_delay; //<! Delay in ms to show the OSD.
 
 	QString file_settings_method; //!< Method to be used for saving file settings
 
@@ -195,6 +199,11 @@ public:
 	OptionState use_new_sub_commands; 
 	OptionState change_sub_scale_should_restart;
 
+	//! If true, loading an external subtitle will be done
+	//! by using the sub_load slave command. Otherwise
+	//! mplayer will be restarted.
+	bool fast_load_sub;
+
 	// ASS styles
 	AssStyles ass_styles;
 	bool force_ass_styles; // Use ass styles even for ass files
@@ -232,6 +241,7 @@ public:
 	bool log_smplayer;
 	QString log_filter;
 	bool verbose_log;
+	bool save_smplayer_log;
 
     //mplayer log autosaving
     bool autosave_mplayer_log;
@@ -283,7 +293,6 @@ public:
 #if STYLE_SWITCHING
 	QString style; 	//!< SMPlayer look
 #endif
-	bool show_frame_counter;
 	bool show_motion_vectors;
 
 	// Function of mouse buttons:
@@ -297,6 +306,7 @@ public:
 
 	QFlags<WheelFunctions> wheel_function_cycle;
 
+	bool wheel_function_seeking_reverse;
 
 	// Configurable seeking
 	int seeking1; // By default 10s
@@ -308,6 +318,11 @@ public:
 #if ENABLE_DELAYED_DRAGGING	
 	int time_slider_drag_delay;
 #endif
+#if SEEKBAR_RESOLUTION
+	//! If true, seeking will be done using a
+	//! percentage (with fractions) instead of time.
+	bool relative_seeking;  
+#endif
 
 	QString language;
 	QString iconset;
@@ -388,8 +403,8 @@ public:
 
 	AudioEqualizerList initial_audio_equalizer;
 
-	//! Default value for panscan (1.0 = no zoom)
-	double initial_panscan_factor;
+	//! Default value for zoom (1.0 = no zoom)
+	double initial_zoom_factor;
 
 	//! Default value for position of subtitles on screen
 	//! 100 = 100% at the bottom
