@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -52,6 +52,17 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 	xv_adaptors = DeviceInfo::xvAdaptors();
 #endif
 
+	// Screensaver
+#ifdef Q_OS_WIN
+	screensaver_check->hide();
+#else
+	screensaver_group->hide();
+#endif
+
+#ifdef Q_OS_WIN
+	vdpau_filters_check->hide();
+#endif
+
 	// Channels combo
 	channels_combo->addItem( "2", MediaSettings::ChStereo );
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
@@ -80,8 +91,6 @@ QPixmap PrefGeneral::sectionIcon() {
 void PrefGeneral::retranslateStrings() {
 	retranslateUi(this);
 
-    initial_volume_label->setNum( initial_volume_slider->value() );
-
 	channels_combo->setItemText(0, tr("2 (Stereo)") );
 	channels_combo->setItemText(1, tr("4 (4.0 Surround)") );
 	channels_combo->setItemText(2, tr("6 (5.1 Surround)") );
@@ -133,12 +142,18 @@ void PrefGeneral::retranslateStrings() {
 
 void PrefGeneral::setData(Preferences * pref) {
 	setMplayerPath( pref->mplayer_bin );
+
+	setUseScreenshots( pref->use_screenshot );
 	setScreenshotDir( pref->screenshot_directory );
 
 	QString vo = pref->vo;
 	if (vo.isEmpty()) {
 #ifdef Q_OS_WIN
-		vo = "directx,";
+		if (QSysInfo::WindowsVersion >= QSysInfo::WV_VISTA) {
+			vo = "direct3d,";
+		} else {
+			vo = "directx,";
+		}
 #else
 		vo = "xv,";
 #endif
@@ -146,9 +161,6 @@ void PrefGeneral::setData(Preferences * pref) {
 	setVO( vo );
 
 	QString ao = pref->ao;
-#ifndef Q_OS_WIN
-	if (ao.isEmpty()) ao = "alsa,";
-#endif
 	setAO( ao );
 
 	setRememberSettings( !pref->dont_remember_media_settings );
@@ -163,26 +175,40 @@ void PrefGeneral::setData(Preferences * pref) {
 
 	setEq2( pref->use_soft_video_eq );
 	setUseAudioEqualizer( pref->use_audio_equalizer );
+	setGlobalVolume( pref->global_volume );
 	setSoftVol( pref->use_soft_vol );
 	setAc3DTSPassthrough( pref->use_hwac3 );
 	setInitialVolNorm( pref->initial_volnorm );
 	setAmplification( pref->softvol_max );
 	setInitialPostprocessing( pref->initial_postprocessing );
 	setInitialDeinterlace( pref->initial_deinterlace );
-	setInitialZoom( pref->initial_panscan_factor );
+	setInitialZoom( pref->initial_zoom_factor );
 	setDirectRendering( pref->use_direct_rendering );
 	setDoubleBuffer( pref->use_double_buffer );
 	setUseSlices( pref->use_slices );
 	setStartInFullscreen( pref->start_in_fullscreen );
-	setDisableScreensaver( pref->disable_screensaver );
 	setBlackbordersOnFullscreen( pref->add_blackborders_on_fullscreen );
 	setAutoq( pref->autoq );
 
-	setInitialVolume( pref->initial_volume );
-	setDontChangeVolume( pref->dont_change_volume );
-	setUseVolume( pref->use_volume_option );
+#ifdef Q_OS_WIN
+	setAvoidScreensaver( pref->avoid_screensaver );
+	setTurnScreensaverOff( pref->turn_screensaver_off );
+#else
+	setDisableScreensaver( pref->disable_screensaver );
+#endif
+
+#ifndef Q_OS_WIN
+	setDisableFiltersWithVdpau( pref->disable_video_filters_with_vdpau );
+#endif
+
 	setAudioChannels( pref->initial_audio_channels );
 	setScaleTempoFilter( pref->use_scaletempo );
+
+	setAutoSyncActivated( pref->autosync );
+	setAutoSyncFactor( pref->autosync_factor );
+
+	setMcActivated( pref->use_mc );
+	setMc( pref->mc_value );
 }
 
 void PrefGeneral::getData(Preferences * pref) {
@@ -201,14 +227,17 @@ void PrefGeneral::getData(Preferences * pref) {
 		//setDrivers( i.voList(), i.aoList() );
 	}
 
+	TEST_AND_SET(pref->use_screenshot, useScreenshots());
 	TEST_AND_SET(pref->screenshot_directory, screenshotDir());
 	TEST_AND_SET(pref->vo, VO());
     TEST_AND_SET(pref->ao, AO());
 
 	bool dont_remember_ms = !rememberSettings();
     TEST_AND_SET(pref->dont_remember_media_settings, dont_remember_ms);
+
 	bool dont_remember_time = !rememberTimePos();
     TEST_AND_SET(pref->dont_remember_time_pos, dont_remember_time);
+
 	if (pref->file_settings_method != fileSettingsMethod()) {
 		pref->file_settings_method = fileSettingsMethod();
 		filesettings_method_changed = true;
@@ -225,29 +254,43 @@ void PrefGeneral::getData(Preferences * pref) {
 
 	TEST_AND_SET(pref->use_soft_video_eq, eq2());
 	TEST_AND_SET(pref->use_soft_vol, softVol());
+	pref->global_volume = globalVolume();
 	TEST_AND_SET(pref->use_audio_equalizer, useAudioEqualizer());
 	TEST_AND_SET(pref->use_hwac3, Ac3DTSPassthrough());
 	pref->initial_volnorm = initialVolNorm();
 	TEST_AND_SET(pref->softvol_max, amplification());
 	pref->initial_postprocessing = initialPostprocessing();
 	pref->initial_deinterlace = initialDeinterlace();
-	pref->initial_panscan_factor = initialZoom();
+	pref->initial_zoom_factor = initialZoom();
 	TEST_AND_SET(pref->use_direct_rendering, directRendering());
 	TEST_AND_SET(pref->use_double_buffer, doubleBuffer());
 	TEST_AND_SET(pref->use_slices, useSlices());
 	pref->start_in_fullscreen = startInFullscreen();
-	TEST_AND_SET(pref->disable_screensaver, disableScreensaver());
 	if (pref->add_blackborders_on_fullscreen != blackbordersOnFullscreen()) {
 		pref->add_blackborders_on_fullscreen = blackbordersOnFullscreen();
 		if (pref->fullscreen) requires_restart = true;
 	}
 	TEST_AND_SET(pref->autoq, autoq());
 
-	pref->initial_volume = initialVolume();
-	pref->dont_change_volume = dontChangeVolume();
-	pref->use_volume_option = useVolume();
+#ifdef Q_OS_WIN
+	pref->avoid_screensaver = avoidScreensaver();
+	TEST_AND_SET(pref->turn_screensaver_off, turnScreensaverOff());
+#else
+	TEST_AND_SET(pref->disable_screensaver, disableScreensaver());
+#endif
+
+#ifndef Q_OS_WIN
+	TEST_AND_SET(pref->disable_video_filters_with_vdpau, disableFiltersWithVdpau());
+#endif
+
 	pref->initial_audio_channels = audioChannels();
 	TEST_AND_SET(pref->use_scaletempo, scaleTempoFilter());
+
+	TEST_AND_SET(pref->autosync, autoSyncActivated());
+	TEST_AND_SET(pref->autosync_factor, autoSyncFactor());
+
+	TEST_AND_SET(pref->use_mc, mcActivated());
+	TEST_AND_SET(pref->mc_value, mc());
 }
 
 void PrefGeneral::updateDriverCombos() {
@@ -341,6 +384,14 @@ QString PrefGeneral::mplayerPath() {
 	return mplayerbin_edit->text();
 }
 
+void PrefGeneral::setUseScreenshots(bool b) {
+	use_screenshots_check->setChecked(b);
+}
+
+bool PrefGeneral::useScreenshots() {
+	return use_screenshots_check->isChecked();
+}
+
 void PrefGeneral::setScreenshotDir( QString path ) {
 	screenshot_edit->setText( path );
 }
@@ -375,10 +426,12 @@ QString PrefGeneral::VO() {
 	QString vo = vo_combo->itemData(vo_combo->currentIndex()).toString();
 	if (vo == "user_defined") {
 		vo = vo_user_defined_edit->text();
+		/*
 		if (vo.isEmpty()) {
 			vo = vo_combo->itemData(0).toString();
 			qDebug("PrefGeneral::VO: user defined vo is empty, using %s", vo.toUtf8().constData());
 		}
+		*/
 	}
 	return vo;
 }
@@ -387,10 +440,12 @@ QString PrefGeneral::AO() {
 	QString ao = ao_combo->itemData(ao_combo->currentIndex()).toString();
 	if (ao == "user_defined") {
 		ao = ao_user_defined_edit->text();
+		/*
 		if (ao.isEmpty()) {
 			ao = ao_combo->itemData(0).toString();
 			qDebug("PrefGeneral::AO: user defined ao is empty, using %s", ao.toUtf8().constData());
 		}
+		*/
 	}
 	return ao;
 }
@@ -483,10 +538,50 @@ void PrefGeneral::setSoftVol(bool b) {
 	softvol_check->setChecked(b);
 }
 
+void PrefGeneral::setGlobalVolume(bool b) {
+	global_volume_check->setChecked(b);
+}
+
+bool PrefGeneral::globalVolume() {
+	return global_volume_check->isChecked();
+}
+
 bool PrefGeneral::softVol() {
 	return softvol_check->isChecked();
 }
 
+void PrefGeneral::setAutoSyncFactor(int factor) {
+	autosync_spin->setValue(factor);
+}
+
+int PrefGeneral::autoSyncFactor() {
+	return autosync_spin->value();
+}
+
+void PrefGeneral::setAutoSyncActivated(bool b) {
+	autosync_check->setChecked(b);
+}
+
+bool PrefGeneral::autoSyncActivated() {
+	return autosync_check->isChecked();
+}
+
+void PrefGeneral::setMc(double value) {
+	mc_spin->setValue(value);
+}
+
+double PrefGeneral::mc() {
+	return mc_spin->value();
+}
+
+void PrefGeneral::setMcActivated(bool b) {
+	use_mc_check->setChecked(b);
+}
+
+bool PrefGeneral::mcActivated() {
+	return use_mc_check->isChecked();
+}
+
 void PrefGeneral::setUseAudioEqualizer(bool b) {
 	audio_equalizer_check->setChecked(b);
 }
@@ -577,14 +672,6 @@ int PrefGeneral::amplification() {
 	return softvol_max_spin->value();
 }
 
-void PrefGeneral::setInitialVolume(int v) {
-	initial_volume_slider->setValue(v);
-}
-
-int PrefGeneral::initialVolume() {
-	return initial_volume_slider->value();
-}
-
 void PrefGeneral::setAudioChannels(int ID) {
 	int pos = channels_combo->findData(ID);
 	if (pos != -1) {
@@ -603,22 +690,6 @@ int PrefGeneral::audioChannels() {
 	}
 }
 
-void PrefGeneral::setDontChangeVolume(bool b) {
-	change_volume_check->setChecked(!b);
-}
-
-bool PrefGeneral::dontChangeVolume() {
-	return !change_volume_check->isChecked();
-}
-
-void PrefGeneral::setUseVolume(Preferences::OptionState value) {
-	use_volume_combo->setState(value);
-}
-
-Preferences::OptionState PrefGeneral::useVolume() {
-	return use_volume_combo->state();
-}
-
 void PrefGeneral::setStartInFullscreen(bool b) {
 	start_fullscreen_check->setChecked(b);
 }
@@ -627,6 +698,23 @@ bool PrefGeneral::startInFullscreen() {
 	return start_fullscreen_check->isChecked();
 }
 
+#ifdef Q_OS_WIN
+void PrefGeneral::setAvoidScreensaver(bool b) {
+	avoid_screensaver_check->setChecked(b);
+}
+
+bool PrefGeneral::avoidScreensaver() {
+	return avoid_screensaver_check->isChecked();
+}
+
+void PrefGeneral::setTurnScreensaverOff(bool b) {
+	turn_screensaver_off_check->setChecked(b);
+}
+
+bool PrefGeneral::turnScreensaverOff() {
+	return turn_screensaver_off_check->isChecked();
+}
+#else
 void PrefGeneral::setDisableScreensaver(bool b) {
 	screensaver_check->setChecked(b);
 }
@@ -634,6 +722,17 @@ void PrefGeneral::setDisableScreensaver(bool b) {
 bool PrefGeneral::disableScreensaver() {
 	return screensaver_check->isChecked();
 }
+#endif
+
+#ifndef Q_OS_WIN
+void PrefGeneral::setDisableFiltersWithVdpau(bool b) {
+	vdpau_filters_check->setChecked(b);
+}
+
+bool PrefGeneral::disableFiltersWithVdpau() {
+	return vdpau_filters_check->isChecked();
+}
+#endif
 
 void PrefGeneral::setBlackbordersOnFullscreen(bool b) {
 	blackborders_on_fs_check->setChecked(b);
@@ -686,12 +785,6 @@ void PrefGeneral::createHelp() {
         tr("If this setting is wrong, SMPlayer won't be able to play "
            "anything!") + "</b>");
 
-	setWhatsThis(screenshot_edit, tr("Screenshots folder"),
-		tr("Here you can specify a folder where the screenshots taken by "
-           "SMPlayer will be stored. If this field is empty the "
-           "screenshot feature will be disabled.") );
-
-
 	setWhatsThis(remember_all_check, tr("Remember settings"),
 		tr("Usually SMPlayer will remember the settings for each file you "
            "play (audio track selected, volume, filters...). Disable this "
@@ -711,6 +804,15 @@ void PrefGeneral::createHelp() {
            "Those ini files will be saved in the folder %1").arg(QString("<i>"+Paths::iniPath()+"/file_settings</i>")) + "</li></ul>" +
 		tr("The latter method could be faster if there is info for a lot of files.") );
 
+	setWhatsThis(use_screenshots_check, tr("Enable screenshots"),
+		tr("You can use this option to enable or disable the possibility to "
+           "take screenshots.") );
+
+	setWhatsThis(screenshot_edit, tr("Screenshots folder"),
+		tr("Here you can specify a folder where the screenshots taken by "
+           "SMPlayer will be stored. If the folder is not valid the "
+           "screenshot feature will be disabled.") );
+
 	setWhatsThis(close_on_finish_check, tr("Close when finished"),
 		tr("If this option is checked, the main window will be automatically "
 		   "closed when the current file/playlist finishes.") );
@@ -732,6 +834,12 @@ void PrefGeneral::createHelp() {
 #endif
 		);
 
+#ifndef Q_OS_WIN
+	setWhatsThis(vdpau_filters_check, tr("Disable video filters when using vdpau"),
+		tr("Usually video filters won't work when using vdpau as video output "
+           "driver, so it's wise to keep this option checked.") );
+#endif
+
 	setWhatsThis(postprocessing_check, tr("Enable postprocessing by default"),
 		tr("Postprocessing will be used by default on new opened files.") );
 
@@ -742,7 +850,8 @@ void PrefGeneral::createHelp() {
 
 	setWhatsThis(deinterlace_combo, tr("Deinterlace by default"),
         tr("Select the deinterlace filter that you want to be used for new "
-           "videos opened.") );
+           "videos opened.") +" "+ 
+        tr("<b>Note:</b> This option won't be used for TV channels.") );
 
 	setWhatsThis(zoom_spin, tr("Default zoom"),
 		tr("This option sets the default zoom which will be used for "
@@ -782,11 +891,25 @@ void PrefGeneral::createHelp() {
            "some video drivers (like gl) are already able to display the "
            "subtitles automatically in the black borders.") */ );
 
+#ifdef Q_OS_WIN
+	setWhatsThis(turn_screensaver_off_check, tr("Switch screensaver off"),
+		tr("This option switches the screensaver off just before starting to "
+           "play a file and switches it on when playback finishes. If this "
+           "option is enabled, the screensaver won't appear even if playing "
+           "audio files or when a file is paused."));
+
+	setWhatsThis(avoid_screensaver_check, tr("Avoid screensaver"),
+		tr("When this option is checked, SMPlayer will try to prevent the "
+           "screensaver to be shown when playing a video file. The screensaver "
+           "will be allowed to be shown if playing an audio file or in pause "
+           "mode. This option only works if the SMPlayer window is in "
+		   "the foreground."));
+#else
 	setWhatsThis(screensaver_check, tr("Disable screensaver"),
 		tr("Check this option to disable the screensaver while playing.<br>"
            "The screensaver will enabled again when play finishes.")
-           //+ tr("<br><b>Note:</b> This option works only in X11 and Windows.")
 		);
+#endif
 
 	// Audio tab
 	addSectionTitle(tr("Audio"));
@@ -807,7 +930,9 @@ void PrefGeneral::createHelp() {
 		tr("Check this option if you want to use the audio equalizer.") );
 
 	setWhatsThis(hwac3_check, tr("AC3/DTS pass-through S/PDIF"),
-		tr("Uses hardware AC3 passthrough") );
+		tr("Uses hardware AC3 passthrough.") + "<br>" +
+        tr("<b>Note:</b> none of the audio filters will be used when this "
+           "option is enabled.") );
 
 	setWhatsThis(channels_combo, tr("Channels by default"),
 		tr("Requests the number of playback channels. MPlayer "
@@ -824,6 +949,12 @@ void PrefGeneral::createHelp() {
 		tr("Allows to change the playback speed without altering pitch. "
            "Requires at least MPlayer dev-SVN-r24924.") );
 
+	setWhatsThis(global_volume_check, tr("Global volume"),
+		tr("If this option is checked, the same volume will be used for "
+           "all files you play. If the option is not checked each "
+           "file uses its own volume.") + "<br>" +
+        tr("This option also applies for the mute control.") );
+
 	setWhatsThis(softvol_check, tr("Software volume control"),
 		tr("Check this option to use the software mixer, instead of "
            "using the sound card mixer.") );
@@ -838,19 +969,12 @@ void PrefGeneral::createHelp() {
 	setWhatsThis(volnorm_check, tr("Volume normalization by default"),
 		tr("Maximizes the volume without distorting the sound.") );
 
-	setWhatsThis(change_volume_check, tr("Change volume"),
-		tr("If checked, SMPlayer will remember the volume for every file "
-           "and will restore it when played again. For new files the default "
-           "volume will be used.") );
-
-	setWhatsThis(use_volume_combo, tr("Change volume just before playing"),
-		tr("If this option is checked the initial volume will be set just "
-           "before playback starts. This avoids a loud volume on startup. "
-           "Requires at least MPlayer SVN r27872."));
-
-	setWhatsThis(initial_volume_slider, tr("Default volume"),
-		tr("Sets the initial volume that new files will use.") );
+	setWhatsThis(autosync_check, tr("Audio/video auto synchronization"),
+		tr("Gradually adjusts the A/V sync based on audio delay "
+           "measurements.") );
 
+	setWhatsThis(mc_spin, tr("A-V sync correction"),
+		tr("Maximum A-V sync correction per frame (in seconds)") );
 
 	addSectionTitle(tr("Preferred audio and subtitles"));
 
