@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -117,6 +117,11 @@ protected:
 	bool disableScreensaver();
 #endif
 
+#ifndef Q_OS_WIN
+	void setDisableFiltersWithVdpau(bool b);
+	bool disableFiltersWithVdpau();
+#endif
+
 	void setBlackbordersOnFullscreen(bool b);
 	bool blackbordersOnFullscreen();
 
