@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2010 Ricardo Villalba <rvm@escomposlinux.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -75,6 +75,9 @@ protected:
 	void setWheelFunctionCycle(QFlags<Preferences::WheelFunctions> flags);
 	QFlags<Preferences::WheelFunctions> wheelFunctionCycle();
 
+	void setWheelFunctionSeekingReverse(bool b);
+	bool wheelFunctionSeekingReverse();
+
 protected:
 	virtual void retranslateStrings();
 };
